Query

Struct Query 

pub struct Query { /* private fields */ }
Represents a database query within the rincon driver.

This struct holds the AQL query string and the query parameters needed to call the ArangoDB server to execute the database query.

Implementations

Source

impl Query

pub fn new<Q>(query_string: Q) -> Self
where Q: Into<String>,

Constructs a new Query with the given query string.

pub fn unwrap(self) -> (String, HashMap<String, Value>)

Moves the fields out of the Query struct to reuse their values without cloning them.

After calling this function this Query instance is invalid.

pub fn str(&self) -> &str

Returns the query string as a &str.

pub fn set_parameter<N, T>(&mut self, name: N, value: T)
where N: Into<String>, T: Into<Value>,

Sets the value of a named parameter.

pub fn parameter<T>(&self, name: &str) -> Option<&T>
where T: UnwrapValue,

Returns the value of a named parameter.