pub struct Query { /* private fields */ }Expand description
Represents a database query within the rincon driver.
This struct holds the AQL query string and the query parameters needed to call the ArangoDB server to execute the database query.
Implementations
Sourceimpl Query
impl Query
Sourcepub fn unwrap(self) -> (String, HashMap<String, Value>)
pub fn unwrap(self) -> (String, HashMap<String, Value>)
Moves the fields out of the Query struct to reuse their values
without cloning them.
After calling this function this Query instance is invalid.
Sourcepub fn set_parameter<N, T>(&mut self, name: N, value: T)
pub fn set_parameter<N, T>(&mut self, name: N, value: T)
Sets the value of a named parameter.